@@ -1,8 +1,6 @@
 """
-Module containing methods for interacting with the FRED API
+FRED API requests.
 """
-import asyncio
-from datetime import date
 from typing import Dict, Any
 
 import pandas as pd
@@ -13,7 +11,7 @@ from algoralabs.data.fred import FredQuery
 from algoralabs.decorators.data import data_request, async_data_request
 
 
-def transform_fred_observations(data: Dict[str, Any]) -> DataFrame:
+def _transform_fred_observations(data: Dict[str, Any]) -> DataFrame:
     return pd.DataFrame(data['observations'])
 
 
@@ -25,37 +23,31 @@ def _get_series_info(query: FredQuery) -> dict:
     }
 
 
-@data_request(transformer=transform_fred_observations)
+@data_request(transformer=_transform_fred_observations)
 def get_series(query: FredQuery) -> DataFrame:
     """
+    Get FRED series.
 
+    Args:
+        query (FredQuery): FRED query
+
+    Returns:
+        DataFrame: DataFrame
     """
     request_info = _get_series_info(query)
     return __get_request(**request_info)
 
 
-@async_data_request(transformer=transform_fred_observations)
+@async_data_request(transformer=_transform_fred_observations)
 async def async_get_series(query: FredQuery) -> DataFrame:
     """
+    Asynchronously get FRED series.
 
+    Args:
+        query (FredQuery): FRED query
+
+    Returns:
+        DataFrame: DataFrame
     """
     request_info = _get_series_info(query)
     return await __async_get_request(**request_info)
-
-
-async def main():
-    rf_series = await async_get_series(
-        FredQuery(
-            api_key='cf546a3e4c455f3e2f295e75acddd6bb',
-            series_id='DGS1MO',
-            observation_start=date(2022, 1, 1)
-        )
-    )
-
-    print(rf_series)
-
-
-if __name__ == "__main__":
-    loop = asyncio.get_event_loop()
-    loop.run_until_complete(main())
-    loop.close()
