@@ -1,5 +1,5 @@
 """
-Module containing methods for interacting with the IEX energy API
+IEX energy API requests.
 """
 from pandas import DataFrame
 
@@ -26,11 +26,11 @@ def historical_oil_prices(symbol: str, **kwargs) -> DataFrame:
     Reference: https://iexcloud.io/docs/api/#time-series-endpoint
 
     Args:
-        symbol: "DCOILWTICO" or "DCOILBRENTEU"
+        symbol (str): "DCOILWTICO" or "DCOILBRENTEU"
         **kwargs: Optional args to pass to the IEX API
 
     Returns:
-        Historical oil prices for the provided symbol
+        DataFrame: Historical oil prices for the provided symbol
     """
     params = __build_params(**kwargs)
     return __base_request(f"time-series/energy/{symbol}", **params)
@@ -44,12 +44,12 @@ async def async_historical_oil_prices(symbol: str, **kwargs) -> DataFrame:
     Reference: https://iexcloud.io/docs/api/#time-series-endpoint
 
     Args:
-        symbol: "DCOILWTICO" or "DCOILBRENTEU"
+        symbol (str): "DCOILWTICO" or "DCOILBRENTEU"
         **kwargs: Optional args to pass to the IEX API
 
     Returns:
-        Historical oil prices for the provided symbol
+        DataFrame: Historical oil prices for the provided symbol
     """
     # default query params
     params = __build_params(**kwargs)
-    return await __async_base_request(f"time-series/energy/{symbol}", **params)
\ No newline at end of file
+    return await __async_base_request(f"time-series/energy/{symbol}", **params)
