@@ -1,11 +1,12 @@
 """
-Module containing methods for interacting with the IEX stocks API
+IEX stocks API requests.
 """
 from typing import List, Union, Dict
+
 from pandas import DataFrame
 
-from algoralabs.data.iex.utils import __base_request, __async_base_request
 from algoralabs.common.functions import no_transform, transform_one_or_many
+from algoralabs.data.iex.utils import __base_request, __async_base_request
 from algoralabs.decorators.data import data_request, async_data_request
 
 
@@ -23,7 +24,7 @@ def symbols() -> DataFrame:
     Reference: https://iexcloud.io/docs/api/#symbols
 
     Returns:
-         IEX supported symbols
+         DataFrame: IEX supported symbols
     """
     request_info = _symbols_request_info()
     return __base_request(**request_info)
@@ -32,12 +33,12 @@ def symbols() -> DataFrame:
 @async_data_request
 async def async_symbols() -> DataFrame:
     """
-    Async wrapper for IEX's API to get symbols that IEX Cloud supports for intraday price updates.
+    Asynchronous wrapper for IEX's API to get symbols that IEX Cloud supports for intraday price updates.
 
     Reference: https://iexcloud.io/docs/api/#symbols
 
     Returns:
-        IEX supported symbols
+        DataFrame: IEX supported symbols
     """
     request_info = _symbols_request_info()
     return await __async_base_request(**request_info)
@@ -70,11 +71,11 @@ def historical_prices(*symbol: str, **kwargs) -> Union[DataFrame, Dict[str, Data
     Reference: https://iexcloud.io/docs/api/#time-series-endpoint
 
     Args:
-         symbol: (*str) Stock symbol(s), such as "AAPL" or "AAPL", "FB"
+         symbol (*str): Stock symbol(s), such as "AAPL" or "AAPL", "FB"
          **kwargs: Optional args to pass to the IEX API
 
     Returns:
-        Historical prices for the symbol(s) requested
+        Union[DataFrame, Dict[str, DataFrame]]: Historical prices for the symbol(s) requested
     """
     # default query params
     request_info = _historical_prices_request_info(*symbol, **kwargs)
@@ -84,16 +85,16 @@ def historical_prices(*symbol: str, **kwargs) -> Union[DataFrame, Dict[str, Data
 @async_data_request(transformer=lambda d: transform_one_or_many(d, 'chart'))
 async def async_historical_prices(*symbol: str, **kwargs) -> Union[DataFrame, Dict[str, DataFrame]]:
     """
-    Async wrapper for IEX's Historical Prices via Time Series API
+    Asynchronous wrapper for IEX's Historical Prices via Time Series API
 
     Reference: https://iexcloud.io/docs/api/#time-series-endpoint
 
     Args:
-         symbol: (*str) Stock symbol(s), such as "AAPL" or "AAPL", "FB"
+         symbol (*str): Stock symbol(s), such as "AAPL" or "AAPL", "FB"
          **kwargs: Optional args to pass to the IEX API
 
     Returns:
-        Historical prices for the symbol(s) requested
+        Union[DataFrame, Dict[str, DataFrame]]: Historical prices for the symbol(s) requested
     """
     # default query params
     request_info = _historical_prices_request_info(*symbol, **kwargs)
@@ -115,11 +116,11 @@ def news(symbol: str, **kwargs) -> DataFrame:
     Reference: https://iexcloud.io/docs/api/#news
 
     Args:
-        symbol: (str) Stock symbol, such as AAPL
+        symbol (str): Stock symbol, such as AAPL
         **kwargs: Optional args to pass to the IEX API
 
     Returns:
-        News for the symbol requested
+        DataFrame: News for the symbol requested
     """
     request_info = _news_request_info(symbol, kwargs)
     return __base_request(**request_info)
@@ -128,15 +129,15 @@ def news(symbol: str, **kwargs) -> DataFrame:
 @async_data_request
 async def async_news(symbol: str, **kwargs) -> DataFrame:
     """
-    Async wrapper for IEX's API to get news for given symbol
+    Asynchronous wrapper for IEX's API to get news for given symbol
     Reference: https://iexcloud.io/docs/api/#news
 
     Args:
-        symbol: (str) Stock symbol, such as AAPL
+        symbol (str): Stock symbol, such as AAPL
         **kwargs: Optional args to pass to the IEX API
 
     Returns:
-        News for the symbol requested
+        DataFrame: News for the symbol requested
     """
     request_info = _news_request_info(symbol, kwargs)
     return await __async_base_request(**request_info)
@@ -156,10 +157,10 @@ def peer_group(symbol: str) -> List[str]:
     Reference: https://iexcloud.io/docs/api/#peers
 
     Args:
-        symbol: (str) Stock symbol, such as AAPL
+        symbol (str): Stock symbol, such as AAPL
 
     Returns:
-         List of symbols
+         List[str]: List of symbols
     """
     request_info = _peer_group_request_info(symbol)
     return __base_request(**request_info)
@@ -168,17 +169,15 @@ def peer_group(symbol: str) -> List[str]:
 @async_data_request(transformer=no_transform)
 async def async_peer_group(symbol: str) -> List[str]:
     """
-    Async wrapper for IEX's API to get stock peers
+    Asynchronous wrapper for IEX's API to get stock peers
 
     Reference: https://iexcloud.io/docs/api/#peers
 
     Args:
-        symbol: (str) Stock symbol, such as AAPL
+        symbol (str): Stock symbol, such as AAPL
 
     Returns:
-         List of symbols
+         List[str]: List of symbols
     """
     request_info = _peer_group_request_info(symbol)
     return await __async_base_request(**request_info)
-
-
