@@ -1,5 +1,5 @@
 """
-Module containing util methods for IEX interaction
+IEX API requests.
 """
 from algoralabs.common.requests import __get_request, __async_get_request
 
@@ -13,24 +13,24 @@ def __base_request(extension: str, **kwargs):
     Base request util for IEX API calls
 
     Args:
-        extension: URI extension
-        **kwargs: request query params
+        extension (str): URI extension
+        **kwargs: Request query params
 
     Returns:
-        IEX repsponse
+        Response: HTTP response object
     """
     return __get_request(endpoint=__build_url(extension), params=kwargs)
 
 
 async def __async_base_request(extension: str, **kwargs):
     """
-    Async base request util for IEX API calls
+    Asynchronous base request util for IEX API calls
 
     Args:
-        extension: URI extension
-        **kwargs: request query params
+        extension (str): URI extension
+        **kwargs: Request query params
 
     Returns:
-        IEX repsponse
+        Response: HTTP response object
     """
     return await __async_get_request(endpoint=__build_url(extension), params=kwargs)
