@@ -1,5 +1,5 @@
 """
-Module containing util methods for interacting with the algoralabs' sdr API
+SDR API request utilities.
 """
 from typing import Optional, Union, Any, Dict
 
@@ -22,13 +22,13 @@ def __transform_filter(filter: Union[FieldFilter, APIFieldFilter]) -> APIFieldFi
 
 def transform_data_filter(data_filter: Optional[DataFilter]) -> Optional[Dict[str, Any]]:
     """
-    Transforms a data filter to a dict
+    Transforms a data filter to dict.
 
     Args:
-        data_filter: Data filter to convert to a dict
+        data_filter (Optional[DataFilter]): Data filter to convert to a dict
 
     Returns:
-        A dict representation of a data filter
+        Optional[Dict[str, Any]]: A dict representation of a data filter
     """
     if data_filter is not None:
         transformed_filter = DataFilter(
