@@ -3,7 +3,7 @@ from typing import Optional, Union, List
 
 from algoralabs.common.base import Base
 
-from algoralabs.common.enum import FieldType
+from algoralabs.common import FieldType
 
 
 class FieldFill(Enum):
